==> job-scheduler_0.22.7.tar.xz: 64/translations/job-scheduler_fr_BE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr_BE">
<context>
    <name>CronModel</name>
    <message>
        <location filename="../CronModel.cpp" line="114"/>
        <source>Time</source>
        <translation>Evénement</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="116"/>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="118"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
</context>
<context>
    <name>ExecuteList</name>
    <message>
        <location filename="../ExecuteList.cpp" line="36"/>
        <source>Max Item</source>
        <translation>Job max</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="38"/>
        <source>Max Date</source>
        <translation>Date max</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="40"/>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="44"/>
        <source>&amp;Update</source>
        <translation>Mise à &amp;jour</translation>
    </message>
</context>
<context>
    <name>ExecuteModel</name>
    <message>
        <location filename="../ExecuteModel.cpp" line="63"/>
        <source>Execute Time</source>
        <translation>Moment d&apos;exécution</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="65"/>
        <source>Time</source>
        <translation>Evénement</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="67"/>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="69"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="49"/>
        <source>&amp;Command</source>
        <translation>Comman&amp;de</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="51"/>
        <source>&amp;Variables</source>
        <translation>&amp;Variables</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="53"/>
        <source>&amp;Job List</source>
        <translation>Liste des &amp;tâches</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="94"/>
        <location filename="../MainWindow.cpp" line="191"/>
        <location filename="../MainWindow.cpp" line="242"/>
        <location filename="../MainWindow.cpp" line="263"/>
        <location filename="../MainWindow.cpp" line="333"/>
        <source>Job Scheduler</source>
        <translation>Ordonnanceur des tâches</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="118"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="119"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="122"/>
        <source>&amp;New Item</source>
        <translation>Nouveau jo&amp;b</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="123"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="126"/>
        <source>&amp;Reload</source>
        <translation>Rec&amp;harger</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="127"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="129"/>
        <source>&amp;Save</source>
        <translation>Enre&amp;gistrer</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="130"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="133"/>
        <source>Start as &amp;Root</source>
        <translation>Démarrer en tant &amp;que Root</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="135"/>
        <source>Start as &amp;Regular user</source>
        <translation>Démarrer en tant qu&apos;&amp;utilisateur régulier</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="136"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="140"/>
        <source>E&amp;xit</source>
        <translation>Sort&amp;ir</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="141"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="148"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editer</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="149"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="151"/>
        <source>Cu&amp;t</source>
        <translation>Cou&amp;per</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="152"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="154"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="155"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="157"/>
        <source>&amp;Paste</source>
        <translation>Co&amp;ller</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="158"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="161"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="162"/>
        <source>Del</source>
        <translation>Suppr</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="173"/>
        <location filename="../MainWindow.cpp" line="176"/>
        <source>&amp;Help</source>
        <translation>Aide &amp;?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="175"/>
        <source>&amp;About</source>
        <translation>A propos &amp;de</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="243"/>
        <source>Not saved since last change.
Are you OK to reload?</source>
        <translation>Pas sauvegardé depuis la dernière modification.
Êtes-vous prêt à recharger ?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="334"/>
        <source>Not saved since last change.
Are you OK to exit?</source>
        <translation>Pas sauvegardé depuis la dernière modification.
Pouvez-vous sortir ?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="346"/>
        <source>About Job Scheduler</source>
        <translation>À propos de l&apos;ordonnanceur de tâches</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="347"/>
        <source>&lt;b&gt;Job Scheduler&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ordonnanceur de tâches&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="347"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="348"/>
        <source>Job Scheduler is based upon qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</source>
        <translation>L&apos;ordonnanceur de tâches - Job Scheduler - est basé sur qroneko 0.5.4, publié en 2005 par korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="349"/>
        <source>Original project page: %1</source>
        <translation>Page originale du projet: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="350"/>
        <source>MX project page: %1</source>
        <translation>Page du projet MX: %1</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../SaveDialog.cpp" line="19"/>
        <source>Save New Schedule</source>
        <translation>Sauver nouvelle planification</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="32"/>
        <source>User:</source>
        <translation>Utilisateur :</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="40"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="41"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>TCommandEdit</name>
    <message>
        <location filename="../TCommandEdit.cpp" line="40"/>
        <source>User:</source>
        <translation>Utilisateur :</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="48"/>
        <source>Time:</source>
        <translation>Evénement :</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="51"/>
        <source>Time String E&amp;ditor</source>
        <translation>Editeur chaîne du te&amp;mps</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="55"/>
        <source>Command:</source>
        <translation>Commande:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="61"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="64"/>
        <source>Job Schedule:</source>
        <translation>Ordonnance de tâches:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="126"/>
        <source>Time Format Error</source>
        <translation>Erreur de format d&apos;heure</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="143"/>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="145"/>
        <source>Tomorrow</source>
        <translation>Demain</translation>
    </message>
</context>
<context>
    <name>TimeDialog</name>
    <message>
        <location filename="../TimeDialog.cpp" line="75"/>
        <source>time</source>
        <translation>événement</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="80"/>
        <source>Minute</source>
        <translation>Minutes</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="92"/>
        <source>Hour</source>
        <translation>Heure</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="98"/>
        <source>AM </source>
        <translation>AM </translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="104"/>
        <source>PM </source>
        <translation>PM </translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="111"/>
        <source>Day</source>
        <translation>Jour</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="126"/>
        <source>Month</source>
        <translation>Mois</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="140"/>
        <source>Week</source>
        <translation>Semaine</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="152"/>
        <source>Simple</source>
        <translation>Simple</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="166"/>
        <source>Enable Literal</source>
        <translation>Activer Literal</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="168"/>
        <source>&amp;Reset</source>
        <translation>&amp;Réinitialiser</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="169"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="170"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>VariableEdit</name>
    <message>
        <location filename="../VariableEdit.cpp" line="46"/>
        <source>Variables</source>
        <translation>Variables</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="51"/>
        <source>Mail:</source>
        <translation>Courrier :</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="52"/>
        <source>Don&apos;t send</source>
        <translation>Pas envoyer</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="53"/>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="54"/>
        <source>To</source>
        <translation>À</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="66"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="69"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="77"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="82"/>
        <source>Value:</source>
        <translation>Valeur :</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="85"/>
        <source>Comment:</source>
        <translation>Commentaire :</translation>
    </message>
</context>
<context>
    <name>VariableModel</name>
    <message>
        <location filename="../VariableModel.cpp" line="37"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../VariableModel.cpp" line="39"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
</context>
</TS>

==> job-scheduler_0.22.10.01.tar.xz: 64/translations/job-scheduler_fr_BE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_BE">
<context>
    <name>CronModel</name>
    <message>
        <location filename="../CronModel.cpp" line="114"/>
        <source>Time</source>
        <translation>Evénement</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="116"/>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="118"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
</context>
<context>
    <name>ExecuteList</name>
    <message>
        <location filename="../ExecuteList.cpp" line="36"/>
        <source>Max Item</source>
        <translation>Job max</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="38"/>
        <source>Max Date</source>
        <translation>Date max</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="40"/>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="44"/>
        <source>&amp;Update</source>
        <translation>Mise à &amp;jour</translation>
    </message>
</context>
<context>
    <name>ExecuteModel</name>
    <message>
        <location filename="../ExecuteModel.cpp" line="63"/>
        <source>Execute Time</source>
        <translation>Moment d&apos;exécution</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="65"/>
        <source>Time</source>
        <translation>Evénement</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="67"/>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="69"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="50"/>
        <source>&amp;Command</source>
        <translation>Comman&amp;de</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="52"/>
        <source>&amp;Variables</source>
        <translation>&amp;Variables</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="54"/>
        <source>&amp;Job List</source>
        <translation>Liste des &amp;tâches</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="95"/>
        <location filename="../MainWindow.cpp" line="188"/>
        <location filename="../MainWindow.cpp" line="233"/>
        <location filename="../MainWindow.cpp" line="254"/>
        <location filename="../MainWindow.cpp" line="324"/>
        <source>Job Scheduler</source>
        <translation>Ordonnanceur des tâches</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="119"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="120"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="123"/>
        <source>&amp;New Item</source>
        <translation>Nouveau jo&amp;b</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="124"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="127"/>
        <source>&amp;Reload</source>
        <translation>Rec&amp;harger</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="128"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="130"/>
        <source>&amp;Save</source>
        <translation>Enre&amp;gistrer</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="131"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="134"/>
        <source>Start as &amp;Root</source>
        <translation>Démarrer en tant &amp;que Root</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="136"/>
        <source>Start as &amp;Regular user</source>
        <translation>Démarrer en tant qu&apos;&amp;utilisateur régulier</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="137"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="141"/>
        <source>E&amp;xit</source>
        <translation>Qu&amp;itter</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="142"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="149"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editer</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="150"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="152"/>
        <source>Cu&amp;t</source>
        <translation>Cou&amp;per</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="153"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="155"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="156"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="158"/>
        <source>&amp;Paste</source>
        <translation>Co&amp;ller</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="159"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="162"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="163"/>
        <source>Del</source>
        <translation>Suppr</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="174"/>
        <location filename="../MainWindow.cpp" line="177"/>
        <source>&amp;Help</source>
        <translation>Aide &amp;?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="176"/>
        <source>&amp;About</source>
        <translation>A propos &amp;de</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="234"/>
        <source>Not saved since last change.
Are you OK to reload?</source>
        <translation>Pas sauvegardé depuis la dernière modification.
Êtes-vous prêt à recharger?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="325"/>
        <source>Not saved since last change.
Are you OK to exit?</source>
        <translation>Pas sauvegardé depuis la dernière modification.
Pouvez-vous sortir?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>About Job Scheduler</source>
        <translation>À propos de l&apos;ordonnanceur de tâches</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>&lt;b&gt;Job Scheduler&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ordonnanceur de tâches&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="339"/>
        <source>Job Scheduler is based upon qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</source>
        <translation>L&apos;ordonnanceur de tâches - Job Scheduler - est basé sur qroneko 0.5.4, publié en 2005 par korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="340"/>
        <source>Original project page: %1</source>
        <translation>Page originale du projet: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="341"/>
        <source>MX project page: %1</source>
        <translation>Page du projet MX: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="343"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../SaveDialog.cpp" line="19"/>
        <source>Save New Schedule</source>
        <translation>Sauver nouvelle planification</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="32"/>
        <source>User:</source>
        <translation>Utilisateur:</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="40"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="41"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>TCommandEdit</name>
    <message>
        <location filename="../TCommandEdit.cpp" line="40"/>
        <source>User:</source>
        <translation>Utilisateur:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="48"/>
        <source>Time:</source>
        <translation>Evénement:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="51"/>
        <source>Time String E&amp;ditor</source>
        <translation>Editeur chaîne du te&amp;mps</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="55"/>
        <source>Command:</source>
        <translation>Commande:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="61"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="64"/>
        <source>Job Schedule:</source>
        <translation>Ordonnance de tâches:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="126"/>
        <source>Time Format Error</source>
        <translation>Erreur de format d&apos;heure</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="143"/>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="145"/>
        <source>Tomorrow</source>
        <translation>Demain</translation>
    </message>
</context>
<context>
    <name>TimeDialog</name>
    <message>
        <location filename="../TimeDialog.cpp" line="75"/>
        <source>time</source>
        <translation>événement</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="80"/>
        <source>Minute</source>
        <translation>Minutes</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="92"/>
        <source>Hour</source>
        <translation>Heure</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="98"/>
        <source>AM </source>
        <translation>AM </translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="104"/>
        <source>PM </source>
        <translation>PM </translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="111"/>
        <source>Day</source>
        <translation>Jour</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="126"/>
        <source>Month</source>
        <translation>Mois</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="140"/>
        <source>Week</source>
        <translation>Semaine</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="152"/>
        <source>Simple</source>
        <translation>Simple</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="166"/>
        <source>Enable Literal</source>
        <translation>Activer Literal</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="168"/>
        <source>&amp;Reset</source>
        <translation>&amp;Réinitialiser</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="169"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="170"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>VariableEdit</name>
    <message>
        <location filename="../VariableEdit.cpp" line="46"/>
        <source>Variables</source>
        <translation>Variables</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="51"/>
        <source>Mail:</source>
        <translation>Courrier:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="52"/>
        <source>Don&apos;t send</source>
        <translation>Pas envoyer</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="53"/>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="54"/>
        <source>To</source>
        <translation>À</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="66"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="69"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="77"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="82"/>
        <source>Value:</source>
        <translation>Valeur:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="85"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
</context>
<context>
    <name>VariableModel</name>
    <message>
        <location filename="../VariableModel.cpp" line="37"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../VariableModel.cpp" line="39"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
</context>
</TS>
